#include <stdio.h>
#include <FL/Fl.H>
#include <FL/Fl_Box.H>
#include <FL/Fl_Window.H>
#include <FL/names.h>

void print_event(Fl_Widget *w,int e)
{
  static int last_event = -1;
  static int num = 0;
  if (e == last_event && (e == FL_DND_DRAG || e == FL_MOVE || e == FL_DRAG))
    return;
  last_event = e;
  num++;
  printf(
    "%4d - %-12.12s, Event: %2d - %s\n",
    num,
    w->label(),
    e,
    fl_eventnames[e]);
  fflush(stdout);
}

class TestWindow : public Fl_Window
{
  int handle(int e)
  {
    if (e == FL_ENTER)
      return 1;
    else if (e == FL_LEAVE)
      return 1;
    else if (e == FL_DND_ENTER)
    {
      print_event(this, e);
      color(FL_YELLOW);
      redraw();
      return 1;
    }
    else if (e == FL_DND_LEAVE)
    {
      print_event(this, e);
      color(FL_GRAY);
      redraw();
      return 1;
    }
    else if (e == FL_DND_DRAG)
    {
      print_event(this, e);
      return 1;
    }
    return 0;
  }

public:
  TestWindow(int w, int h, const char *c) : Fl_Window(w, h, c) { }
  TestWindow(int x, int y, int w, int h, const char *c) : Fl_Window(x, y, w, h, c) { }
};

int main(int argc, char **argv)
{
  TestWindow window(400, 400, "outer");
  TestWindow inner(100,100,200,200,"inner");
  inner.end();
  inner.box(FL_DOWN_BOX);
  inner.color(fl_lighter(FL_BLUE));
  inner.align(FL_ALIGN_CENTER);
  window.end();
  window.show(argc, argv);
  inner.show();
  return Fl::run();
}
